﻿Option Explicit On

Imports XSP
Imports XCM
Imports System.Runtime.ConstrainedExecution

''' ---------------------------------------------
''' <summary>
''' バーコードラベルReport出力　継承元クラス
''' </summary>
''' <remarks>
''' Copyright 2013 FUJITSU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public MustInherit Class BCP020R000

#Region "解放処理"
	'確実な解放処理を実行するために指定
	Inherits CriticalFinalizerObject
	'解放処理を実装する為に指定
	Implements IDisposable
	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2013/01/09 新規作成 ID)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overridable Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
			Try
				If disposing Then
					' マネージリソースの解放
					_pValueFrm = Nothing						'フォーム
					_pValuePrint = Nothing						'印刷フラグ
					_pValueDgv = Nothing						'一覧
					_pValueKuhaku = Nothing						'空白
					_pValueBusu = Nothing						'部数
				End If
			Finally
				' アンマネージリソースの解放、終了時に必ず行う処理
			End Try
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2013/01/09 新規作成 ID)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		MyBase.Finalize()
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2013/01/09 新規作成 ID)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

#Region "変数"
	'IN項目
	Private _pValueFrm As frmBase = Nothing									'フォーム
	Private _pValuePrint As Boolean											'印刷フラグ
	Private _pValueDgv As New DataGridView									'一覧
	Private _pValueKuhaku As Integer = Nothing								'空白
	Private _pValueBusu As Integer = Nothing								'部数
#End Region

#Region "コンスタント"
	Private Const CST_LOG_PRODUCT As String = ""							'ログ記述用コンスト変数
	Private Const CST_LOG_CLASS As String = "バーコードラベル（Report）"	'ログ記述用コンスト変数
	Private Const CST_TEXTFLG_DATE As String = "2"							'区分テキストフラグ='2'（日付）
	Private Const CST_PATIENT_MINNO As Integer = 1							'患者番号桁位置最小値
	Private Const CST_PATIENT_MAXNO As Integer = 10							'患者番号桁位置最大値
	Private Const CST_ENV_MI As String = "MI"								'連結順[管理物コード + 患者番号]
	Private Const CST_ENV_IM As String = "IM"								'連結順[患者番号 + 管理物コード]
	Private Const CST_ENV_I As String = "I"									'連結順[患者番号]
#End Region

#Region "コンストラクタ"

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' ※BCP020F010から呼び出されたとき
	''' </summary>
	''' <param name="pForm">frmBase</param>
	''' <param name="pValuePrint">印刷フラグ</param>
	''' <param name="pData">一覧</param>
	''' <param name="pKuhaku">空白</param>
	''' <param name="pBusu">部数</param>			
	''' <remarks>
	''' 2013/01/09 新規作成 ID)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New(ByVal pForm As Form, ByVal pValuePrint As Boolean, ByVal pData As DataGridView, ByVal pKuhaku As Integer, ByVal pBusu As Integer)
		_pValueFrm = pForm
		_pValuePrint = pValuePrint
		_pValueDgv = pData
		_pValueKuhaku = pKuhaku
		_pValueBusu = pBusu
	End Sub

#End Region

#Region "メソッド"

	''' ---------------------------------------------
	''' <summary>
	''' 印刷・プレビュー処理
	''' </summary>	
	''' <remarks>
	''' 2013/01/09 新規作成 ID)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function exeReport() As Boolean
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "exeReport", CST_LOG_PRODUCT, CST_LOG_CLASS, "印刷・プレビュー処理 START")
		Dim pMeiNo As Integer = 1										'明細番号
		'Dim pDataRow As DataRow = Nothing								'取得データ１行分
		Dim FilePath As String = Nothing								'mdbファイルパス
		Dim cliAccess As clsXTM_PRINTSETTING_ACCESS						'印刷設定情報クラス
		Dim datAccess As datXTM_PRINTSETTING_ACCESS_OneRec = Nothing	'印刷設定情報１件分
		Dim cliCom As clsCom											'共通メソッドクラス
		Try
			cliAccess = New clsXTM_PRINTSETTING_ACCESS
			cliCom = New clsCom
			' 印刷設定情報取得
			datAccess = cliAccess.getAccessSettingOneRec(Me._pValueFrm.Name, Me.GetType.Name)
			If datAccess Is Nothing Then
				Return False
			End If
			'MDBのパスを取得
			FilePath = cliCom.setReportPath(datAccess.FILE_NM)
			Using cliReportFunc As New clsReportFunc(Me._pValueFrm, FilePath, datAccess.REPORT_NM, Me._pValuePrint)
				' ＤＢ更新処理
				Using db As New clsDB(clsSysMst.ctlConfigData)
					'ワークテーブルの削除
					cliReportFunc.exeHeaderDel(db, Me.GetType.Name, True)
					cliReportFunc.exeWorkDel(db, Me.GetType.Name, sqlBCP020R000.sqlDel_Data, sqlBCP020R000.prmPRT_ID, sqlBCP020R000.prmHOST_NM)
					'ヘッダーワークテーブルの追加
					cliReportFunc.exeHeaderIns(db, Me.getHeaderData, True)
					'ワークテーブル更新処理
					If setWorkData(db) = False Then Return False
				End Using
				'■■■いったんプレビュー印刷処理はコメント化
				' ﾌﾟﾚﾋﾞｭｰ・印刷処理
				If cliReportFunc.AcPrint(datAccess.NUMBERPRINTED) = True Then
					'MessageBox.Show("ワークテーブルに出力しました。", Me._pValueFrm.Text)
				Else
					Return False
				End If
			End Using

			Return True
		Catch ex As Exception
			Throw
		Finally
			pMeiNo = Nothing
			cliAccess = Nothing
			datAccess = Nothing
			cliCom = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ヘッダーデータ編集
	''' </summary>
	''' <returns>ヘッダーデータ</returns>
	''' <remarks>
	''' 2013/01/09 新規作成 ID)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getHeaderData() As datHeader
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "getHeaderData", CST_LOG_PRODUCT, CST_LOG_CLASS, "ヘッダーデータ取得 START")
		Dim retHeader As datHeader
		Try
			retHeader = New datHeader
			With retHeader
				.PRT_ID = Me.GetType.Name							'帳票ID	
			End With
			Return retHeader
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ワークデータ作成処理
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <returns>True:成功 False:失敗</returns>
	''' <remarks>
	''' 2013/01/09 新規作成 ID)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function setWorkData(ByVal db As clsDB) As Boolean
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "setWorkData", CST_LOG_PRODUCT, CST_LOG_CLASS, "ワークテーブル更新 START")
		Dim pMeiNo As Integer = 1									'明細番号
		Dim pDataRow As DataRow = Nothing							'取得データ１行分
		Dim datHedder As datHeader = Nothing						'ヘッダー情報クラス
		Dim row As DataRow
		Try
			With db
				' ＳＱＬ文セット
				.setSQL(sqlBCP020R000.sqlIns_Data)
				' パラメータデータ型セット
				Me.setSqlParm(db)
				' 空白の数だけ空白行を作成
				For i As Integer = 1 To Me._pValueKuhaku
					.setVal(sqlBCP020R000.prmDSPORDER, pMeiNo)		'表示順パラメータ値セット
					.execNonQuery(True)								'INSERT文実行
					pMeiNo += 1										'明細No加算
				Next i
				For Each pRow As DataGridViewRow In Me._pValueDgv.Rows
					row = CType(pRow.DataBoundItem, DataRowView).Row
					'チェック＝ONのみ出力
					If row(sqlBCP020R000.itmSELECTED).ToString = CStr(clsConst.Enum_CheckBox_Flg.CheckOn) Then
						'部数分だけ同じデータをワークテーブルに追加する。
						For i As Integer = 1 To Me._pValueBusu
							Me.setParm(db, row, pMeiNo)				'パラメータセット
							.execNonQuery(True)						'INSERT文実行
							pMeiNo += 1								'明細No加算
						Next i
					End If
				Next
			End With
			Return True
		Catch ex As Exception
			Throw
		Finally
			datHedder = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータデータ型設定
	''' </summary>
	''' <param name="db">クラスMDB</param>
	''' <remarks>
	''' 2013/01/09 新規作成 ID)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub setSqlParm(ByVal db As clsDB)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "setSqlParm", CST_LOG_PRODUCT, CST_LOG_CLASS, "パラメータデータ型セット START")
		Try
			With db
				' パラメータデータ型設定
				.setParam(sqlBCP020R000.prmHOST_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmBYOREKI_NO, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmPATIENT_KNM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmPATIENT_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmGENDER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmGENDER_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmBIRTH_DT, clsDB.Enum_dbType.dbDateTime)
				.setParam(sqlBCP020R000.prmMNGITEM_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmMNGITEM_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmDIV1_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmDIV1_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmDIV2_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmDIV2_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmDATE1, clsDB.Enum_dbType.dbDateTime)
				.setParam(sqlBCP020R000.prmDATE2, clsDB.Enum_dbType.dbDateTime)
				.setParam(sqlBCP020R000.prmFIRSTRECEIVING_DT, clsDB.Enum_dbType.dbDateTime)
				.setParam(sqlBCP020R000.prmLASTRECEIVING_DT, clsDB.Enum_dbType.dbDateTime)
				.setParam(sqlBCP020R000.prmRECIPIENT_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmRECIPIENT_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmMNGSTATUS_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmMNGSTATUS_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmKEEPLCT_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmKEEPLCT_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmDOCTOR_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmDOCTOR_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmMNGITEMCMB1_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmMNGITEMCMB1_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmMNGITEMCMB2_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmMNGITEMCMB2_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmMNGITEMTEXT1, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmMNGITEMTEXT2, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmMNGITEMCHK1, clsDB.Enum_dbType.dbInt)
				.setParam(sqlBCP020R000.prmMNGITEMCHK2, clsDB.Enum_dbType.dbInt)
				.setParam(sqlBCP020R000.prmMNGITEMCHK3, clsDB.Enum_dbType.dbInt)
				.setParam(sqlBCP020R000.prmMNGITEMCHK4, clsDB.Enum_dbType.dbInt)
				.setParam(sqlBCP020R000.prmVOLUMEKEY_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmMNGITEM_REMARKS, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmBARCODE, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmCHECK_FLG, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmDSPORDER, clsDB.Enum_dbType.dbInt)
				.setParam(sqlBCP020R000.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP020R000.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			End With
			' パラメータ値設定(一旦すべてNullをセット)
			Me.setParm_Space(db)
		Catch ex As Exception
			Throw
		End Try

	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータセット
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="pRow">１レコードデータ</param>
	''' <param name="MeiNo">表示順</param>
	''' <remarks>
	''' 2013/01/09 新規作成 ID)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub setParm(ByVal db As clsDB, ByVal pRow As DataRow, ByVal MeiNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "setParm", CST_LOG_PRODUCT, CST_LOG_CLASS, "MDB登録パラメータセット START")
		Dim wrkEnvMI As String							'"MI"の組合せ2文字
		Dim wrkEnvSta As Integer = CST_PATIENT_MINNO	'患者番号開始位置
		Dim wrkEnvEnd As Integer = CST_PATIENT_MAXNO	'患者番号終了位置
		Dim wrkBARCODE As String = Nothing				'バーコード編集用
		Dim wrkPatient As String						'患者番号編集用
		Dim wrkDate As String = Nothing					'日付形式編集用
		Try
			wrkPatient = pRow(sqlBCP020R000.itmPATIENT_NO).ToString
			With db
				' 共通パラメータ値設定
				.setVal(sqlBCP020R000.prmDSPORDER, MeiNo)
				.setVal(sqlBCP020R000.prmPATIENT_NO, pRow(sqlBCP020R000.itmPATIENT_NO).ToString)
				.setVal(sqlBCP020R000.prmBYOREKI_NO, pRow(sqlBCP020R000.itmBYOREKI_NO).ToString)
				.setVal(sqlBCP020R000.prmPATIENT_NM, pRow(sqlBCP020R000.itmPATIENT_NM).ToString)
				.setVal(sqlBCP020R000.prmPATIENT_KNM, pRow(sqlBCP020R000.itmPATIENT_KNM).ToString)
				.setVal(sqlBCP020R000.prmGENDER_CD, pRow(sqlBCP020R000.itmGENDER_CD).ToString)
				.setVal(sqlBCP020R000.prmGENDER_NM, pRow(sqlBCP020R000.itmGENDER_NM).ToString)
				.setVal(sqlBCP020R000.prmBIRTH_DT, chkDbDate(pRow(sqlBCP020R000.itmBIRTH_DT).ToString))
				.setVal(sqlBCP020R000.prmMNGITEM_CD, pRow(sqlBCP020R000.itmMNGITEM_CD).ToString)
				.setVal(sqlBCP020R000.prmMNGITEM_NM, pRow(sqlBCP020R000.itmMNGITEM_NM).ToString)
				.setVal(sqlBCP020R000.prmDIV1_CD, pRow(sqlBCP020R000.itmDIV1_CD).ToString)
				.setVal(sqlBCP020R000.prmDIV1_NM, pRow(sqlBCP020R000.itmDIV1_NM).ToString)
				.setVal(sqlBCP020R000.prmDIV2_CD, pRow(sqlBCP020R000.itmDIV2_CD).ToString)
				.setVal(sqlBCP020R000.prmDIV2_NM, pRow(sqlBCP020R000.itmDIV2_NM).ToString)
				.setVal(sqlBCP020R000.prmDATE1, chkDbDate(pRow(sqlBCP020R000.itmDATE1).ToString))
				.setVal(sqlBCP020R000.prmDATE2, chkDbDate(pRow(sqlBCP020R000.itmDATE2).ToString))
				.setVal(sqlBCP020R000.prmFIRSTRECEIVING_DT, chkDbDate(pRow(sqlBCP020R000.itmFIRSTRECEIVING_DT).ToString))
				.setVal(sqlBCP020R000.prmLASTRECEIVING_DT, chkDbDate(pRow(sqlBCP020R000.itmLASTRECEIVING_DT).ToString))
				.setVal(sqlBCP020R000.prmRECIPIENT_CD, pRow(sqlBCP020R000.itmRECIPIENT_CD).ToString)
				.setVal(sqlBCP020R000.prmRECIPIENT_NM, pRow(sqlBCP020R000.itmRECIPIENT_NM).ToString)
				.setVal(sqlBCP020R000.prmMNGSTATUS_CD, pRow(sqlBCP020R000.itmMNGSTATUS_CD).ToString)
				.setVal(sqlBCP020R000.prmMNGSTATUS_NM, pRow(sqlBCP020R000.itmMNGSTATUS_NM).ToString)
				.setVal(sqlBCP020R000.prmKEEPLCT_CD, pRow(sqlBCP020R000.itmKEEPLCT_CD).ToString)
				.setVal(sqlBCP020R000.prmKEEPLCT_NM, pRow(sqlBCP020R000.itmKEEPLCT_NM).ToString)
				.setVal(sqlBCP020R000.prmDOCTOR_CD, pRow(sqlBCP020R000.itmDOCTOR_CD).ToString)
				.setVal(sqlBCP020R000.prmDOCTOR_NM, pRow(sqlBCP020R000.itmDOCTOR_NM).ToString)
				.setVal(sqlBCP020R000.prmMNGITEMCMB1_CD, pRow(sqlBCP020R000.itmMNGITEMCMB1_CD).ToString)
				.setVal(sqlBCP020R000.prmMNGITEMCMB1_NM, pRow(sqlBCP020R000.itmMNGITEMCMB1_NM).ToString)
				.setVal(sqlBCP020R000.prmMNGITEMCMB2_CD, pRow(sqlBCP020R000.itmMNGITEMCMB2_CD).ToString)
				.setVal(sqlBCP020R000.prmMNGITEMCMB2_NM, pRow(sqlBCP020R000.itmMNGITEMCMB2_NM).ToString)
				.setVal(sqlBCP020R000.prmMNGITEMTEXT1, pRow(sqlBCP020R000.itmMNGITEMTEXT1).ToString)
				.setVal(sqlBCP020R000.prmMNGITEMTEXT2, pRow(sqlBCP020R000.itmMNGITEMTEXT2).ToString)
				.setVal(sqlBCP020R000.prmMNGITEMCHK1, pRow(sqlBCP020R000.itmMNGITEMCHK1).ToString)
				.setVal(sqlBCP020R000.prmMNGITEMCHK2, pRow(sqlBCP020R000.itmMNGITEMCHK2).ToString)
				.setVal(sqlBCP020R000.prmMNGITEMCHK3, pRow(sqlBCP020R000.itmMNGITEMCHK3).ToString)
				.setVal(sqlBCP020R000.prmMNGITEMCHK4, pRow(sqlBCP020R000.itmMNGITEMCHK4).ToString)
				.setVal(sqlBCP020R000.prmVOLUMEKEY_NM, pRow(sqlBCP020R000.itmVOLUMEKEY_NM).ToString)
				.setVal(sqlBCP020R000.prmMNGITEM_REMARKS, pRow(sqlBCP020R000.itmMNGITEM_REMARKS).ToString)

				'動作環境設定コード()
				'■■■「103」「104」あとで確認する！■■■
				'ENV_00103 = 103 'ﾊﾞｰｺｰﾄﾞ使用
				'ENV_00104 = 104 '印刷表示有無
				'ENV_00105 = 105 '"MI"の組合せ2文字
				'ENV_00106 = 106 '患者番号開始位置
				'ENV_00107 = 107 '患者番号終了位置
				wrkEnvMI = clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00105)
				'動作環境設定TBLから取得できない/取得値が不正の場合は[105→"MI"][106/107→"1-10"]とする
				If wrkEnvMI = CST_ENV_MI Or _
				 wrkEnvMI = CST_ENV_IM Or _
				 wrkEnvMI = CST_ENV_I Then
				Else
					wrkEnvMI = CST_ENV_MI
				End If
				If IsNumeric(clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00106)) = True AndAlso _
				 IsNumeric(clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00107)) = True Then
					wrkEnvSta = CType(clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00106), Integer)
					wrkEnvEnd = CType(clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00107), Integer)
					If wrkEnvSta <= wrkEnvEnd And _
					   wrkEnvSta >= CST_PATIENT_MINNO And _
					   wrkEnvEnd <= CST_PATIENT_MAXNO Then
					Else
						wrkEnvSta = CST_PATIENT_MINNO
						wrkEnvEnd = CST_PATIENT_MAXNO
					End If
				End If
				'バーコード生成
				'患者番号セット
				wrkBARCODE = wrkPatient.Substring(wrkEnvSta - 1, wrkEnvEnd - wrkEnvSta + 1)
				'管理物コード連結
				Select Case wrkEnvMI
					Case CST_ENV_MI	'管理物コード + 患者番号
						wrkBARCODE = pRow(sqlBCP020R000.itmMNGITEM_CD).ToString & wrkBARCODE
					Case CST_ENV_IM	'患者番号 + 管理物コード
						wrkBARCODE &= pRow(sqlBCP020R000.itmMNGITEM_CD).ToString
					Case Else '"I" 管理物コードは連結しない
				End Select
				'区分１コード連結
				If String.IsNullOrEmpty(pRow(sqlBCP020R000.itmDIV1_CD).ToString) = False Then
					wrkBARCODE &= cnvDivCd(pRow(sqlBCP020R000.itmDIV1_CD).ToString, _
							pRow(sqlBCP020R000.itmDIV1TEXT_FLG).ToString)
				End If
				'区分２コード連結
				If String.IsNullOrEmpty(pRow(sqlBCP020R000.itmDIV2_CD).ToString) = False Then
					wrkBARCODE &= cnvDivCd(pRow(sqlBCP020R000.itmDIV2_CD).ToString, _
							pRow(sqlBCP020R000.itmDIV2TEXT_FLG).ToString)
				End If
				.setVal(sqlBCP020R000.prmBARCODE, wrkBARCODE)												'バーコード
				.setVal(sqlBCP020R000.prmCHECK_FLG, clsConst.Enum_CheckBox_Flg.CheckOn)						'チェック							
			End With
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータセット(空白行)
	''' </summary>
	''' <param name="db">クラスMDB</param>
	''' <remarks>
	''' 2013/01/09 新規作成 ID)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub setParm_Space(ByVal db As clsDB)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "setParm_Space", CST_LOG_PRODUCT, CST_LOG_CLASS, "MDB登録パラメータセット(空白行) START")
		Try
			With db
				' パラメータ値設定
				.setVal(sqlBCP020R000.prmHOST_NM, clsConst.CST_HOST_NM)										'ホストID
				.setVal(sqlBCP020R000.prmPATIENT_NO, vbNullString)											'患者番号
				.setVal(sqlBCP020R000.prmBYOREKI_NO, vbNullString)											'病歴番号
				.setVal(sqlBCP020R000.prmPATIENT_KNM, vbNullString)											'カナ
				.setVal(sqlBCP020R000.prmPATIENT_NM, vbNullString)											'氏名
				.setVal(sqlBCP020R000.prmGENDER_CD, vbNullString)											'性別コード
				.setVal(sqlBCP020R000.prmGENDER_NM, vbNullString)											'性別
				.setVal(sqlBCP020R000.prmBIRTH_DT, vbNullString)											'生年月日
				.setVal(sqlBCP020R000.prmMNGITEM_CD, vbNullString)											'管理物コード
				.setVal(sqlBCP020R000.prmMNGITEM_NM, vbNullString)											'管理物名称
				.setVal(sqlBCP020R000.prmDIV1_CD, vbNullString)												'区分１コード
				.setVal(sqlBCP020R000.prmDIV1_NM, vbNullString)												'区分１名称
				.setVal(sqlBCP020R000.prmDIV2_CD, vbNullString)												'区分２コード
				.setVal(sqlBCP020R000.prmDIV2_NM, vbNullString)												'区分２名称
				.setVal(sqlBCP020R000.prmDATE1, vbNullString)												'日付１
				.setVal(sqlBCP020R000.prmDATE2, vbNullString)												'日付２
				.setVal(sqlBCP020R000.prmFIRSTRECEIVING_DT, vbNullString)									'初回受領日
				.setVal(sqlBCP020R000.prmLASTRECEIVING_DT, vbNullString)									'最終受領日
				.setVal(sqlBCP020R000.prmRECIPIENT_CD, vbNullString)										'受領者コード
				.setVal(sqlBCP020R000.prmRECIPIENT_NM, vbNullString)										'受領者
				.setVal(sqlBCP020R000.prmMNGSTATUS_CD, vbNullString)										'管理状況コード
				.setVal(sqlBCP020R000.prmMNGSTATUS_NM, vbNullString)										'管理状況
				.setVal(sqlBCP020R000.prmKEEPLCT_CD, vbNullString)											'保管場所コード
				.setVal(sqlBCP020R000.prmKEEPLCT_NM, vbNullString)											'保管場所名称
				.setVal(sqlBCP020R000.prmDOCTOR_CD, vbNullString)											'医師コード
				.setVal(sqlBCP020R000.prmDOCTOR_NM, vbNullString)											'医師名称
				.setVal(sqlBCP020R000.prmMNGITEMCMB1_CD, vbNullString)										'コンボ１コード
				.setVal(sqlBCP020R000.prmMNGITEMCMB1_NM, vbNullString)										'コンボ１名称
				.setVal(sqlBCP020R000.prmMNGITEMCMB2_CD, vbNullString)										'コンボ２コード
				.setVal(sqlBCP020R000.prmMNGITEMCMB2_NM, vbNullString)										'コンボ２名称
				.setVal(sqlBCP020R000.prmMNGITEMTEXT1, vbNullString)										'テキスト１
				.setVal(sqlBCP020R000.prmMNGITEMTEXT2, vbNullString)										'テキスト２
				.setVal(sqlBCP020R000.prmMNGITEMCHK1, vbNullString)											'チェック１
				.setVal(sqlBCP020R000.prmMNGITEMCHK2, vbNullString)											'チェック２
				.setVal(sqlBCP020R000.prmMNGITEMCHK3, vbNullString)											'チェック３
				.setVal(sqlBCP020R000.prmMNGITEMCHK4, vbNullString)											'チェック４
				.setVal(sqlBCP020R000.prmVOLUMEKEY_NM, vbNullString)										'分冊
				.setVal(sqlBCP020R000.prmMNGITEM_REMARKS, vbNullString)										'管理物備考
				.setVal(sqlBCP020R000.prmBARCODE, vbNullString)												'バーコード
				.setVal(sqlBCP020R000.prmCHECK_FLG, vbNullString)											'チェック
				.setVal(sqlBCP020R000.prmDSPORDER, vbNullString)											'表示順
				.setVal(sqlBCP020R000.prmLASTUPDUSER_CD, clsSysMst.getLoginId)								'更新者コード
				.setVal(sqlBCP020R000.prmLASTUPD_DT, DateTime.Now())										'更新日
			End With
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータ日付チェック
	''' </summary>
	''' <param name="wrkDate">チェックする日付</param>
	''' <remarks>
	''' 2013/01/09 新規作成 ID)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkDbDate(ByVal wrkDate As String) As String
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "chkDbDate", CST_LOG_PRODUCT, CST_LOG_CLASS, "パラメータ日付チェック START")
		Try
			If String.IsNullOrEmpty(wrkDate) = True Then
				Return vbNullString
			Else
				Return FormatDateTime(wrkDate, DateFormat.ShortDate)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 区分１コード、区分２コードを連結用に変換
	''' </summary>
	''' <remarks>
	''' 2013/01/09 新規作成 ID)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function cnvDivCd(ByVal DivCd As String, ByVal TextFlg As String) As String
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "cnvDivCd", CST_LOG_PRODUCT, CST_LOG_CLASS, "区分コード変換 START")

		Try
			'日付の場合→数字のみの8桁に編集
			If TextFlg = CST_TEXTFLG_DATE Then
				cnvDivCd = (CDate(DivCd).Year _
				  & Format(CDate(DivCd).Month, "00") _
				  & Format(CDate(DivCd).Day, "00")).ToString
			Else
				cnvDivCd = DivCd
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function

#End Region

End Class
