﻿Imports XSP
Imports XCM
Imports System.IO
Imports System.Runtime.ConstrainedExecution
Imports System.Windows.Forms
Imports LST.clsLST010F010
Imports XSP.clsExcelFunc

''' ---------------------------------------------
''' <summary>
''' 統計表ＥＸＣＥＬ出力クラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class LST020E010

#Region "解放処理"
	'確実な解放処理を実行するために指定
	Inherits CriticalFinalizerObject
	'解放処理を実装する為に指定
	Implements IDisposable

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/10/07 新規作成 CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
			'ここで変数のクリアを行う
			'解放（Dispose）
			If Me.cliLST010F010 IsNot Nothing Then Me.cliLST010F010.Dispose()

			'解放（Nothing）
			Me.pFrm = Nothing
			Me.cliCom = Nothing
			Me.cliLST010F010 = Nothing
			Me.cliExcelFunc = Nothing
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/10/07 新規作成 CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/10/07 新規作成 CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

#Region "変数"

	Private pFrm As frmBase = Nothing									'フォーム
	Private cliLST010F010 As New clsLST010F010							'統計表選択クラス
	Private cliCom As New clsCom										'共通クラス
	Private cliExcelFunc As New clsExcelFunc							'Excel作業クラス

#End Region

#Region "コンスタント"

	'テンプレートファイル名（未指定時）
	Private Const CST_DEFAULT_TEMPLATE_FILENAME As String = "汎用.xls"

#End Region

#Region "コンストラクタ"

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <param name="pForm">frmBase</param>
	''' <remarks>
	''' 2010/10/07 新規作成 CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New(ByVal pForm As Form)
		pFrm = pForm
	End Sub

#End Region

#Region "メソッド"

	''' ---------------------------------------------
	''' <summary>
	''' 帳票Excel出力処理
	''' </summary>
	''' <param name="pParmSheetData">パラメータ情報</param>
	''' <param name="cTate">取得データクラス</param>
	''' <param name="pFileNm">テンプレートファイル名</param>
	''' <param name="pSheetNm">シート名</param>
	''' <remarks>
	''' 2010/10/07 新規作成 CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function ExePutExcel(ByVal pParmSheetData As PrmShtData, ByVal cTate As List(Of clsTate), ByVal pFileNm As String, ByVal pSheetNm As String) As Boolean
		pFrm.log(clsSysMst.logLevel.DBG, "ExePutExcel", "帳票Excel出力処理 Start")
		Dim bResult As Boolean = False
		Try

			cliLST010F010 = New clsLST010F010
			'パラメータ情報
			cliLST010F010.pPrmShtData = pParmSheetData
			'フルパスを取得
			Dim sFileNm As String
			If String.IsNullOrEmpty(pFileNm) Then
				'未指定の場合は汎用.xlsを雛形として使用する
				sFileNm = cliCom.setExcelTemplatePath(CST_DEFAULT_TEMPLATE_FILENAME)
			Else
				sFileNm = cliLST010F010.GetFileNmForStatistics(pFrm, pFileNm, True)
			End If
			'雛型ファイルのチェック
			If Not File.Exists(sFileNm) Then
				clsSysMst.showMsgEx("E0003", "雛型ファイルが存在しない", "出力", "必要ファイル：" & sFileNm)
				Return bResult
			End If
			'雛形シート名が存在しない場合はエラー
			Dim arSheetNm As ArrayList = cliExcelFunc.getSheetNames(sFileNm)
			Dim FindCnt As Integer = 0
			For i As Integer = 0 To arSheetNm.Count - 1
				If arSheetNm(i).ToString = CST_PARAM_SHEET Or arSheetNm(i).ToString = CST_DATA_SHEET Then
					FindCnt += 1
				End If
			Next
			If FindCnt < 2 Then
				clsSysMst.showMsgEx("E0003", "雛型シートが存在しない", "出力", Nothing)
				Return bResult
			End If
			'最大行列チェック
			Dim errMsgCd As String = String.Empty
			Dim errMsgParm() As String = Nothing
			If Not cliLST010F010.ChkMaxRowColForExcel(pFrm, cTate, sFileNm, True, errMsgCd, errMsgParm) Then
				clsSysMst.showMsgEx(errMsgCd, errMsgParm)
				Return bResult
			End If

			'出力用縦軸データ
			cliLST010F010.cPutTate = cTate

			'Excel出力
			bResult = cliLST010F010.PutExcel(pFrm, False, sFileNm, pSheetNm, True)

		Catch ex As Exception
			Throw
		End Try
		Return bResult

	End Function

#End Region

End Class
